@@ -260,7 +260,7 @@ public class AdminServiceImpl implements AdminService {
             throw new IllegalArgumentException("Instance " + oldName + " not found");
         }
         if (instance.isRoot()) {
-            throw new IllegalArgumentException("Root instance cannot be renamed");
+            throw new IllegalArgumentException("You can't rename the root instance");
         }
         if (instance.getPid() != 0) {
             throw new IllegalStateException("Instance not stopped");
