@@ -17,7 +17,6 @@
 package org.apache.karaf.shell.config;
 
 import java.io.File;
-import java.util.ArrayList;
 import java.util.Dictionary;
 import java.util.Enumeration;
 
@@ -49,7 +48,7 @@ public class UpdateCommand extends ConfigCommandSupport {
     protected void doExecute(ConfigurationAdmin admin) throws Exception {
         Dictionary props = getEditedProps();
         if (props == null) {
-            System.err.println("No configuration is being edited--run the edit command first");
+            System.err.println("No configuration is being edited. Run the edit command first");
             return;
         }
 
@@ -75,20 +74,6 @@ public class UpdateCommand extends ConfigCommandSupport {
                     p.put((String) key, (String) props.get(key));
                 }
             }
-            // remove "removed" properties from the file
-            ArrayList<String> propertiesToRemove = new ArrayList<String>();
-            for (Object key : p.keySet()) {
-                if (props.get(key) == null
-                        && !Constants.SERVICE_PID.equals(key)
-                        && !ConfigurationAdmin.SERVICE_FACTORYPID.equals(key)
-                        && !FELIX_FILEINSTALL_FILENAME.equals(key)) {
-                    propertiesToRemove.add(key.toString());
-                }
-            }
-            for (String key : propertiesToRemove) {
-                p.remove(key);
-            }
-            // save the cfg file
             storage.mkdirs();
             p.save();
         } else {
