@@ -30,12 +30,19 @@ import jline.Terminal;
 import org.apache.felix.service.command.CommandProcessor;
 import org.apache.felix.service.command.CommandSession;
 import org.apache.felix.service.command.Function;
+import org.apache.karaf.jaas.modules.JaasHelper;
 import org.apache.karaf.jaas.modules.UserPrincipal;
 import org.fusesource.jansi.AnsiConsole;
 import org.osgi.framework.BundleContext;
 
 public class ConsoleFactory {
 
+    private static final Class[] SECURITY_BUGFIX = {
+            JaasHelper.class,
+            JaasHelper.OsgiSubjectDomainCombiner.class,
+            JaasHelper.DelegatingProtectionDomain.class,
+    };
+
     private BundleContext bundleContext;
     private CommandProcessor commandProcessor;
     private TerminalFactory terminalFactory;
@@ -69,7 +76,7 @@ public class ConsoleFactory {
             Subject subject = new Subject();
             final String user = "karaf";
             subject.getPrincipals().add(new UserPrincipal(user));
-            Subject.doAs(subject, new PrivilegedExceptionAction<Object>() {
+            JaasHelper.doAs(subject, new PrivilegedExceptionAction<Object>() {
                 public Object run() throws Exception {
                     doStart(user);
                     return null;
