@@ -16,10 +16,8 @@
  */
 package org.apache.karaf.shell.osgi;
 
-import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.karaf.shell.console.MultiException;
 import org.osgi.framework.Bundle;
 import org.apache.felix.gogo.commands.Command;
 
@@ -27,15 +25,9 @@ import org.apache.felix.gogo.commands.Command;
 public class StopBundle extends BundlesCommand {
 	
 	protected void doExecute(List<Bundle> bundles) throws Exception {
-        List<Exception> exceptions = new ArrayList<Exception>();
         for (Bundle bundle : bundles) {
-            try {
-                bundle.stop();
-            } catch (Exception e) {
-                exceptions.add(new Exception("Unable to stop bundle " + bundle.getBundleId(), e));
-            }
+            bundle.stop();
         }
-        MultiException.throwIf("Error stopping bundles", exceptions);
     }
 
 }
